function recordData (trialOrder, results, alignment, sameDiff, totalTrials, orient)
% prints experimental results in the Command Window and in a text file
% each completed run generates a text file with a new name (number in the
% file name is incremented)

% construct file name for .txt file to print results - includes condition, 
% number of the run for this condition, and .txt file extension
if (orient == 1)
    fnames = dir('dataUpright*');
    fname = strcat('dataUpright', num2str(1+length(fnames)), '.txt');
else
    fnames = dir('dataUpsideDown*');
    fname = strcat('dataUpsideDown', num2str(1+length(fnames)), '.txt');
end

% create vectors of alignment and sameDiff conditions with order determined
% by the randomized trial order
aligns = alignment(trialOrder);
sames = sameDiff(trialOrder);
% used for testing with small number of trials (less than the 80 expected)
aligns = aligns(1:totalTrials);
sames = sames(1:totalTrials);
results = results(1:totalTrials);
% total number of correct trials for "same" conditions in the aligned and
% misaligned image display
sameAlignCorrect = sum(sames & aligns & results);
sameMisCorrect = sum(sames & (aligns == 0) & results);

% string corresponding to type of view
if (orient == 1)
    typeStr = 'upright';
else
    typeStr = 'upside-down';
end

nSameAlign = sum(sames & aligns);       % number of aligned "same" trials
nSameMis = sum(sames & (aligns == 0));  % number of misaligned "same" trials
fid = fopen(fname, 'w');    % open file for storing results (text summary)
str1 = sprintf('Results for trials with same top part of face (eye region) in %s condition \n', typeStr);
str2 = sprintf('Experimental run number %u for this condition\n', 1+length(fnames));
str3 = sprintf('Total number of *same* trials: %u \n', nSameAlign+nSameMis);
alignCorr = 100.0*(sameAlignCorrect/nSameAlign);    % percent correct for
misCorr = 100.0*(sameMisCorrect/nSameMis);          % align & misalign
str4 = sprintf('Percent correct for aligned trials: %4.1f %% correct \n', alignCorr);
str5 = sprintf('Percent correct for misaligned trials: %4.1f %% correct \n', misCorr);
str6 = sprintf('Difference in performance, misaligned - aligned: %4.1f %% \n', misCorr - alignCorr);
% print strings to text file and Command Window
fprintf(fid, [str1 str2 str3]);
fprintf(fid, 'Percent correct for aligned trials: %4.1f %% correct \n', alignCorr);
fprintf(fid, 'Percent correct for misaligned trials: %4.1f %% correct \n', misCorr);
fprintf(fid, 'Difference in performance, misaligned - aligned: %4.1f %% \n', misCorr - alignCorr);
disp([str1 str2 str3 str4 str5 str6]);
fclose(fid);                % close file


